"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Persona_types_1 = require("./Persona.types");
/**
 * These colors are considered reserved colors and can only be set with overrides:
 * - Red is a color that often has a special meaning.
 * - Transparent is not intended to be used with typical initials due to accessibility issues,
 *   its primary use is for Facepile overflow buttons.
 */
var COLOR_SWATCHES_LOOKUP = [
    Persona_types_1.PersonaInitialsColor.green10,
    Persona_types_1.PersonaInitialsColor.darkGreen20,
    Persona_types_1.PersonaInitialsColor.teal10,
    Persona_types_1.PersonaInitialsColor.cyan30,
    Persona_types_1.PersonaInitialsColor.lightBlue30,
    Persona_types_1.PersonaInitialsColor.blue20,
    Persona_types_1.PersonaInitialsColor.darkBlue10,
    Persona_types_1.PersonaInitialsColor.violet10,
    Persona_types_1.PersonaInitialsColor.purple10,
    Persona_types_1.PersonaInitialsColor.magenta10,
    Persona_types_1.PersonaInitialsColor.lightPink10,
    Persona_types_1.PersonaInitialsColor.pink10,
    Persona_types_1.PersonaInitialsColor.pinkRed10,
    Persona_types_1.PersonaInitialsColor.red10,
    Persona_types_1.PersonaInitialsColor.darkRed20,
    Persona_types_1.PersonaInitialsColor.orange10,
    Persona_types_1.PersonaInitialsColor.orange30,
    Persona_types_1.PersonaInitialsColor.orangeYellow20,
    Persona_types_1.PersonaInitialsColor.gray30,
    Persona_types_1.PersonaInitialsColor.gray40,
    Persona_types_1.PersonaInitialsColor.gray20
];
var COLOR_SWATCHES_NUM_ENTRIES = COLOR_SWATCHES_LOOKUP.length;
function getInitialsColorFromName(displayName) {
    var color = Persona_types_1.PersonaInitialsColor.blue;
    if (!displayName) {
        return color;
    }
    var hashCode = 0;
    for (var iLen = displayName.length - 1; iLen >= 0; iLen--) {
        var ch = displayName.charCodeAt(iLen);
        var shift = iLen % 8;
        // tslint:disable-next-line:no-bitwise
        hashCode ^= (ch << shift) + (ch >> (8 - shift));
    }
    color = COLOR_SWATCHES_LOOKUP[hashCode % COLOR_SWATCHES_NUM_ENTRIES];
    return color;
}
function personaInitialsColorToHexCode(personaInitialsColor) {
    switch (personaInitialsColor) {
        case Persona_types_1.PersonaInitialsColor.lightBlue:
        case Persona_types_1.PersonaInitialsColor.lightBlue30:
            return '#4F6BED';
        case Persona_types_1.PersonaInitialsColor.blue:
        case Persona_types_1.PersonaInitialsColor.blue20:
            return '#0078D4';
        case Persona_types_1.PersonaInitialsColor.darkBlue:
        case Persona_types_1.PersonaInitialsColor.darkBlue10:
            return '#004E8C';
        case Persona_types_1.PersonaInitialsColor.teal:
        case Persona_types_1.PersonaInitialsColor.teal10:
            return '#038387';
        case Persona_types_1.PersonaInitialsColor.lightGreen:
        case Persona_types_1.PersonaInitialsColor.green:
        case Persona_types_1.PersonaInitialsColor.green10:
            return '#498205';
        case Persona_types_1.PersonaInitialsColor.darkGreen:
        case Persona_types_1.PersonaInitialsColor.darkGreen20:
            return '#0B6A0B';
        case Persona_types_1.PersonaInitialsColor.lightPink:
        case Persona_types_1.PersonaInitialsColor.lightPink10:
            return '#C239B3';
        case Persona_types_1.PersonaInitialsColor.pink:
        case Persona_types_1.PersonaInitialsColor.pink10:
            return '#E3008C';
        case Persona_types_1.PersonaInitialsColor.magenta:
        case Persona_types_1.PersonaInitialsColor.magenta10:
            return '#881798';
        case Persona_types_1.PersonaInitialsColor.purple:
        case Persona_types_1.PersonaInitialsColor.purple10:
            return '#5C2E91';
        case Persona_types_1.PersonaInitialsColor.orange:
        case Persona_types_1.PersonaInitialsColor.orange10:
            return '#CA5010';
        case Persona_types_1.PersonaInitialsColor.red:
        case Persona_types_1.PersonaInitialsColor.red10:
            return '#D13438';
        case Persona_types_1.PersonaInitialsColor.darkRed:
        case Persona_types_1.PersonaInitialsColor.darkRed20:
            return '#A4262C';
        case Persona_types_1.PersonaInitialsColor.transparent:
            return 'transparent';
        case Persona_types_1.PersonaInitialsColor.violet:
        case Persona_types_1.PersonaInitialsColor.violet10:
            return '#8764B8';
        case Persona_types_1.PersonaInitialsColor.orangeYellow20:
            return '#986F0B';
        case Persona_types_1.PersonaInitialsColor.pinkRed10:
            return '#750B1C';
        case Persona_types_1.PersonaInitialsColor.gray30:
            return '#7A7574';
        case Persona_types_1.PersonaInitialsColor.cyan30:
            return '#005B70';
        case Persona_types_1.PersonaInitialsColor.orange30:
            return '#8E562E';
        case Persona_types_1.PersonaInitialsColor.gray20:
            return '#69797E';
        case Persona_types_1.PersonaInitialsColor.black:
        case Persona_types_1.PersonaInitialsColor.gray40:
            return '#393939';
    }
}
function initialsColorPropToColorCode(props) {
    var primaryText = props.primaryText, text = props.text;
    var initialsColor = props.initialsColor;
    var initialsColorCode;
    if (typeof initialsColor === 'string') {
        initialsColorCode = initialsColor;
    }
    else {
        initialsColor = initialsColor !== undefined ? initialsColor : getInitialsColorFromName(text || primaryText);
        initialsColorCode = personaInitialsColorToHexCode(initialsColor);
    }
    return initialsColorCode;
}
exports.initialsColorPropToColorCode = initialsColorPropToColorCode;
//# sourceMappingURL=PersonaInitialsColor.js.map